==> phonon-backend-vlc-0.6.1.tar.xz: phonon-backend-vlc-0.6.1/src/vlc.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=PhononBackend
MimeType=application/x-annodex;video/quicktime;video/x-quicktime;audio/x-m4a;application/x-quicktimeplayer;video/mkv;video/msvideo;video/x-msvideo;video/x-flic;audio/x-aiff;audio/aiff;audio/x-pn-aiff;audio/x-realaudio;audio/basic;audio/x-basic;audio/x-pn-au;audio/x-8svx;audio/8svx;audio/x-16sv;audio/168sv;image/x-ilbm;image/ilbm;video/x-anim;video/anim;image/png;image/x-png;video/mng;video/x-mng;audio/x-ogg;audio/x-speex+ogg;application/ogg;audio/vnd.rn-realaudio;audio/x-pn-realaudio-plugin;audio/x-real-audio;application/vnd.rn-realmedia;video/mpeg;video/x-mpeg;audio/x-wav;audio/wav;audio/x-pn-wav;audio/x-pn-windows-acm;audio/mpeg2;audio/x-mpeg2;audio/mpeg3;audio/x-mpeg3;audio/mpeg;audio/x-mpeg;audio/x-mpegurl;audio/mp3;video/x-ms-asf;application/x-flash-video;audio/x-it;audio/x-s3m;audio/x-xm;
X-KDE-Library=phonon_vlc
X-KDE-PhononBackendInfo-InterfaceVersion=1
X-KDE-PhononBackendInfo-Version=@PHONON_VLC_VERSION@
X-KDE-PhononBackendInfo-Website=http://www.videolan.org/
Icon=vlc
InitialPreference=10

Name=VLC
Name[bg]=VLC
Name[bs]=VLC
Name[ca]=VLC
Name[ca@valencia]=VLC
Name[cs]=VLC
Name[da]=VLC
Name[de]=VLC
Name[el]=VLC
Name[es]=VLC
Name[et]=VLC
Name[fi]=VLC
Name[fr]=VLC
Name[ga]=VLC
Name[gl]=VLC
Name[hu]=VLC
Name[it]=VLC
Name[kk]=VLC
Name[ko]=VLC
Name[nb]=VLC
Name[nds]=VLC
Name[nl]=VLC
Name[pa]=VLC
Name[pl]=VLC
Name[pt]=VLC
Name[pt_BR]=VLC
Name[ro]=VLC
Name[ru]=VLC
Name[sk]=VLC
Name[sl]=VLC
Name[sr]=ВЛЦ
Name[sr@ijekavian]=ВЛЦ
Name[sr@ijekavianlatin]=VLC
Name[sr@latin]=VLC
Name[sv]=VLC
Name[tr]=VLC
Name[ug]=VLC
Name[uk]=VLC
Name[x-test]=xxVLCxx
Name[zh_CN]=VLC
Name[zh_TW]=VLC

Comment=Phonon VLC backend
Comment[bg]=Ядро VLC за Phonon
Comment[bs]=VLC kao pozadina za Phonon
Comment[ca]=Dorsal del VLC pel Phonon
Comment[ca@valencia]=Dorsal del VLC pel Phonon
Comment[cs]=Podpůrná vrstva VLC
Comment[da]=Phonon VLC-motor
Comment[de]=Phonon-Treiber für VLC
Comment[el]=Σύστημα υποστήριξης Phonon VLC
Comment[es]=Motor VLC para Phonon
Comment[et]=Phononi VLC taustaprogramm
Comment[fi]=Phonon VLC -taustaohjelma
Comment[fr]=Module VLC de Phonon
Comment[ga]=Inneall VLC Phonon
Comment[gl]=Infraestrutura de VLC para Phonon
Comment[hu]=Phonon VLC-backend
Comment[it]=Motore VLC di Phonon
Comment[kk]=Phonon VLC тетігі
Comment[ko]=Phonon VLC 백엔드
Comment[nb]=Phonon VLC-motor
Comment[nds]=VLC-Hülpprogramm för Phonon
Comment[nl]=VLC-backend van Phonon
Comment[pa]=ਫੋਨੋਨ VLC ਬੈਕਐਂਡ
Comment[pl]=Silnik VLC dla Phonon
Comment[pt]=Infra-estrutura do VLC para o Phonon
Comment[pt_BR]=Infraestrutura do VLC para o Phonon
Comment[ro]=Suportul VLC pentru Phonon
Comment[ru]=Механизм VLC для Phonon
Comment[sk]=Backend Phonon VLC
Comment[sl]=Zaledje VLC za Phonon
Comment[sr]=ВЛЦ као позадина Фонона
Comment[sr@ijekavian]=ВЛЦ као позадина Фонона
Comment[sr@ijekavianlatin]=VLC kao pozadina Phonona
Comment[sr@latin]=VLC kao pozadina Phonona
Comment[sv]=Phonon VLC-gränssnitt
Comment[tr]=Phonon VLC arkaucu
Comment[uk]=Модуль VLC Phonon
Comment[x-test]=xxPhonon VLC backendxx
Comment[zh_CN]= Phonon VLC 后端
Comment[zh_TW]=Phonon VLC 後端介面

==> phonon-backend-vlc-0.6.2.tar.xz: phonon-backend-vlc-0.6.2/src/vlc.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=PhononBackend
MimeType=application/x-annodex;video/quicktime;video/x-quicktime;audio/x-m4a;application/x-quicktimeplayer;video/mkv;video/msvideo;video/x-msvideo;video/x-flic;audio/x-aiff;audio/aiff;audio/x-pn-aiff;audio/x-realaudio;audio/basic;audio/x-basic;audio/x-pn-au;audio/x-8svx;audio/8svx;audio/x-16sv;audio/168sv;image/x-ilbm;image/ilbm;video/x-anim;video/anim;image/png;image/x-png;video/mng;video/x-mng;audio/x-ogg;audio/x-speex+ogg;application/ogg;audio/vnd.rn-realaudio;audio/x-pn-realaudio-plugin;audio/x-real-audio;application/vnd.rn-realmedia;video/mpeg;video/x-mpeg;audio/x-wav;audio/wav;audio/x-pn-wav;audio/x-pn-windows-acm;audio/mpeg2;audio/x-mpeg2;audio/mpeg3;audio/x-mpeg3;audio/mpeg;audio/x-mpeg;audio/x-mpegurl;audio/mp3;video/x-ms-asf;application/x-flash-video;audio/x-it;audio/x-s3m;audio/x-xm;audio/prs.sid;audio/x-mod;
X-KDE-Library=phonon_vlc
X-KDE-PhononBackendInfo-InterfaceVersion=1
X-KDE-PhononBackendInfo-Version=@PHONON_VLC_VERSION@
X-KDE-PhononBackendInfo-Website=http://www.videolan.org/
Icon=vlc
InitialPreference=10

Name=VLC
Name[bg]=VLC
Name[bs]=VLC
Name[ca]=VLC
Name[ca@valencia]=VLC
Name[cs]=VLC
Name[da]=VLC
Name[de]=VLC
Name[el]=VLC
Name[es]=VLC
Name[et]=VLC
Name[fi]=VLC
Name[fr]=VLC
Name[ga]=VLC
Name[gl]=VLC
Name[hu]=VLC
Name[it]=VLC
Name[kk]=VLC
Name[ko]=VLC
Name[lt]=VLC
Name[mr]=व्ही-एल-सी
Name[nb]=VLC
Name[nds]=VLC
Name[nl]=VLC
Name[pa]=VLC
Name[pl]=VLC
Name[pt]=VLC
Name[pt_BR]=VLC
Name[ro]=VLC
Name[ru]=VLC
Name[sk]=VLC
Name[sl]=VLC
Name[sr]=ВЛЦ
Name[sr@ijekavian]=ВЛЦ
Name[sr@ijekavianlatin]=VLC
Name[sr@latin]=VLC
Name[sv]=VLC
Name[tr]=VLC
Name[ug]=VLC
Name[uk]=VLC
Name[x-test]=xxVLCxx
Name[zh_CN]=VLC
Name[zh_TW]=VLC

Comment=Phonon VLC backend
Comment[bg]=Ядро VLC за Phonon
Comment[bs]=VLC kao pozadina za Phonon
Comment[ca]=Dorsal del VLC pel Phonon
Comment[ca@valencia]=Dorsal del VLC pel Phonon
Comment[cs]=Podpůrná vrstva VLC
Comment[da]=Phonon VLC-motor
Comment[de]=Phonon-Treiber für VLC
Comment[el]=Σύστημα υποστήριξης Phonon VLC
Comment[es]=Motor VLC para Phonon
Comment[et]=Phononi VLC taustaprogramm
Comment[fi]=Phonon VLC -taustaohjelma
Comment[fr]=Module VLC de Phonon
Comment[ga]=Inneall VLC Phonon
Comment[gl]=Infraestrutura de VLC para Phonon
Comment[hu]=Phonon VLC-backend
Comment[it]=Motore VLC di Phonon
Comment[kk]=Phonon VLC тетігі
Comment[ko]=Phonon VLC 백엔드
Comment[lt]=Phonon VLC galinė sąsaja
Comment[mr]=फोनोन व्ही-एल-सी बॅकएन्ड
Comment[nb]=Phonon VLC-motor
Comment[nds]=VLC-Hülpprogramm för Phonon
Comment[nl]=VLC-backend van Phonon
Comment[pa]=ਫੋਨੋਨ VLC ਬੈਕਐਂਡ
Comment[pl]=Silnik VLC dla Phonon
Comment[pt]=Infra-estrutura do VLC para o Phonon
Comment[pt_BR]=Infraestrutura do VLC para o Phonon
Comment[ro]=Suportul VLC pentru Phonon
Comment[ru]=Механизм VLC для Phonon
Comment[sk]=Backend Phonon VLC
Comment[sl]=Zaledje VLC za Phonon
Comment[sr]=ВЛЦ као позадина Фонона
Comment[sr@ijekavian]=ВЛЦ као позадина Фонона
Comment[sr@ijekavianlatin]=VLC kao pozadina Phonona
Comment[sr@latin]=VLC kao pozadina Phonona
Comment[sv]=Phonon VLC-gränssnitt
Comment[tr]=Phonon VLC arkaucu
Comment[uk]=Модуль VLC Phonon
Comment[x-test]=xxPhonon VLC backendxx
Comment[zh_CN]= Phonon VLC 后端
Comment[zh_TW]=Phonon VLC 後端介面
